% Author: Paul Boudra
% Date: 12/3/2011
% Example serial connection
% Writes 1024 8-bit unsigned numbers, then reads 1024 blocks of 2 16-bit signed numbers
clear all;
close all;

ints = uint8(0:1:1023);

% setup serial connection
disp('Opening connection...');
s = serial('COM1');
set(s,'BaudRate', 115200); % match baud rate to FPGA baud rate
fopen(s);
disp('Open.');
disp(' '); % New Line

% in case any data is left in the line
disp('Flushing buffered data.');
fread(s);
disp('Connection flushed.');
disp(' '); % New Line

% write 1024 8-bit integers
disp('Writing data...');
for count=1:1024
    fwrite(s, ints(count), 'uint8');
end
disp('Data written.');
disp(' '); % New Line

% setup arrays to be written to (optional)
fpga_real = int16(zeros(1, 1024));
fpga_imag = int16(zeros(1, 1024));

% read 2 16-bit integers in expecting 1024 groupings
disp('Reading data...');
for count=1:1024
    fpga_real(count) = fread(s, 1, 'uint16');
    fpga_imag(count) = fread(s, 1, 'uint16');
end
disp('Data successfully read');
disp(' '); % New Line

disp('Closing connection.');
fclose(s);
delete(s);
clear s;
disp('Connection closed.');
disp(' '); % New Line